@@ -62,9 +62,10 @@ public class EditJumpWindow : EditEventWindow
 		}	
 
 		EditJumpWindowBox.weightPercentPreferred = weightPercentPreferred;
-		EditJumpWindowBox.personWeight = SqlitePersonSession.SelectPersonWeight(
+		EditJumpWindowBox.personWeight = SqlitePersonSession.SelectAttribute(
 				Convert.ToInt32(myEvent.PersonID),
-				Convert.ToInt32(myEvent.SessionID)); 
+				Convert.ToInt32(myEvent.SessionID),
+				Constants.Weight); 
 
 		EditJumpWindowBox.pDN = pDN;
 		
@@ -248,7 +249,7 @@ public class EditJumpWindow : EditEventWindow
 			else
 				jumpWeightInKg = Convert.ToDouble(entryWeight);
 			
-			double newPersonWeight = SqlitePersonSession.SelectPersonWeight(personID, mySessionID); 
+			double newPersonWeight = SqlitePersonSession.SelectAttribute(personID, mySessionID, Constants.Weight); 
 			//jumpPercentWeightForNewPerson = jumpWeightInKg * 100 / newPersonWeight; 
 			jumpPercentWeightForNewPerson = Util.WeightFromKgToPercent(jumpWeightInKg, newPersonWeight); 
 			Log.WriteLine(string.Format("oldPW: {0}, jWinKg {1}, newPW{2}, jWin%NewP{3}",
@@ -288,7 +289,8 @@ public class EditJumpRjWindow : EditJumpWindow
 		}
 
 		EditJumpRjWindowBox.weightPercentPreferred = weightPercentPreferred;
-		EditJumpRjWindowBox.personWeight = SqlitePersonSession.SelectPersonWeight(myEvent.PersonID, myEvent.SessionID); 
+		EditJumpRjWindowBox.personWeight = SqlitePersonSession.SelectAttribute(
+				myEvent.PersonID, myEvent.SessionID, Constants.Weight); 
 
 		EditJumpRjWindowBox.pDN = pDN;
 		
@@ -790,15 +792,19 @@ public class JumpExtraWindow
 	[Widget] Gtk.Label label_fall;
 	[Widget] Gtk.Label label_cm;
 	
+	[Widget] Gtk.Label label_dj_arms;
+	[Widget] Gtk.CheckButton check_dj_arms;
+	
 	//for RunAnalysis
 	//but will be used and recorded with "fall"
-	static int distance;
+	static double distance;
 
 	static string option = "Kg";
 	static double limited = 10;
 	static bool jumpsLimited;
-	static int weight = 20;
-	static int fall = 20;
+	static double weight = 20;
+	static bool arms = false;
+	static double fall = 20;
 	
 	static JumpExtraWindow JumpExtraWindowBox;
 	Gtk.Window parent;
@@ -859,10 +865,14 @@ public class JumpExtraWindow
 		if(! myJumpType.HasWeight) {
 			hideWeightData();	
 		}
-		if(myJumpType.StartIn || myJumpType.Name == Constants.TakeOffName || myJumpType.Name == Constants.TakeOffWeightName) {
-			hideFallData();	
-		}
+		if(myJumpType.StartIn || myJumpType.Name == Constants.TakeOffName || myJumpType.Name == Constants.TakeOffWeightName)
+			       hideFallData();	
 		
+		//show technique (arms) only in DJ
+		if(myJumpType.StartIn || myJumpType.IsRepetitive)
+			hideTechniqueArmsData();
+		
+		JumpExtraWindowBox.check_dj_arms.Active = arms;
 		JumpExtraWindowBox.spinbutton_weight.Value = weight;
 		JumpExtraWindowBox.spinbutton_fall.Value = fall;
 		if (option == "Kg") {
@@ -877,22 +887,27 @@ public class JumpExtraWindow
 	}
 	
 	static void hideRepetitiveData () {
-		JumpExtraWindowBox.label_limit.Sensitive = false;
-		JumpExtraWindowBox.spinbutton_limit.Sensitive = false;
-		JumpExtraWindowBox.label_limit_units.Sensitive = false;
+		JumpExtraWindowBox.label_limit.Hide();
+		JumpExtraWindowBox.spinbutton_limit.Hide();
+		JumpExtraWindowBox.label_limit_units.Hide();
 	}
 	
 	static void hideWeightData () {
-		JumpExtraWindowBox.label_weight.Sensitive = false;
-		JumpExtraWindowBox.spinbutton_weight.Sensitive = false;
-		JumpExtraWindowBox.radiobutton_kg.Sensitive = false;
-		JumpExtraWindowBox.radiobutton_weight.Sensitive = false;
+		JumpExtraWindowBox.label_weight.Hide();
+		JumpExtraWindowBox.spinbutton_weight.Hide();
+		JumpExtraWindowBox.radiobutton_kg.Hide();
+		JumpExtraWindowBox.radiobutton_weight.Hide();
+	}
+	
+	static void hideTechniqueArmsData () {
+		JumpExtraWindowBox.label_dj_arms.Hide();
+		JumpExtraWindowBox.check_dj_arms.Hide();
 	}
 	
 	static void hideFallData () {
-		JumpExtraWindowBox.label_fall.Sensitive = false;
-		JumpExtraWindowBox.spinbutton_fall.Sensitive = false;
-		JumpExtraWindowBox.label_cm.Sensitive = false;
+		JumpExtraWindowBox.label_fall.Hide();
+		JumpExtraWindowBox.spinbutton_fall.Hide();
+		JumpExtraWindowBox.label_cm.Hide();
 	}
 	
 	void on_button_cancel_clicked (object o, EventArgs args)
@@ -910,9 +925,10 @@ public class JumpExtraWindow
 	void on_button_accept_clicked (object o, EventArgs args)
 	{
 		limited = (double) spinbutton_limit.Value;
-		weight = (int) spinbutton_weight.Value;
-		fall = (int) spinbutton_fall.Value;
-		distance = (int) spinbutton_fall.Value;
+		weight = (double) spinbutton_weight.Value;
+		fall = (double) spinbutton_fall.Value;
+		distance = (double) spinbutton_fall.Value;
+		arms = check_dj_arms.Active;
 		
 		JumpExtraWindowBox.jump_extra.Hide();
 		JumpExtraWindowBox = null;
@@ -936,41 +952,38 @@ public class JumpExtraWindow
 		get { return button_accept;	}
 	}
 
-	public string Option 
-	{
-		get { return option;	}
+	public string Option {
+		get { return option; }
 	}
 
-	public bool JumpsLimited 
-	{
-		get { return jumpsLimited;	}
+	public bool JumpsLimited {
+		get { return jumpsLimited; }
 	}
 	
-	public double Limited 
-	{
-		get { return limited;	}
+	public double Limited {
+		get { return limited; }
 	}
 	
-	
 	public string LimitString
 	{
 		get { 
-			if(jumpsLimited) {
+			if(jumpsLimited) 
 				return limited.ToString() + "J";
-			} else {
+			else 
 				return Limited.ToString() + "T";
-			}
 		}
 	}
 	
-	public int Weight 
-	{
-		get { return weight;	}
+	public double Weight {
+		get { return weight; }
 	}
 	
-	public int Fall 
-	{
-		get { return fall;	}
+	public bool Arms {
+		get { return arms; }
+	}
+
+	public double Fall {
+		get { return fall; }
 	}
 }
 
@@ -986,11 +999,15 @@ public class JumpsMoreWindow : EventMoreWindow
 	private bool selectedStartIn;
 	private bool selectedExtraWeight;
 
-	public JumpsMoreWindow (Gtk.Window parent) {
+	public JumpsMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
+		this.testOrDelete = testOrDelete;
+		
+		if(!testOrDelete)
+			jumps_runs_more.Title = Catalog.GetString("Delete test type defined by user");
 		
 		//put an icon to window
 		UtilGtk.IconWindow(jumps_runs_more);
@@ -1003,10 +1020,10 @@ public class JumpsMoreWindow : EventMoreWindow
 		initializeThings();
 	}
 	
-	static public JumpsMoreWindow Show (Gtk.Window parent)
+	static public JumpsMoreWindow Show (Gtk.Window parent, bool testOrDelete)
 	{
 		if (JumpsMoreWindowBox == null) {
-			JumpsMoreWindowBox = new JumpsMoreWindow (parent);
+			JumpsMoreWindowBox = new JumpsMoreWindow (parent, testOrDelete);
 		}
 		JumpsMoreWindowBox.jumps_runs_more.Show ();
 		
@@ -1043,14 +1060,16 @@ public class JumpsMoreWindow : EventMoreWindow
 			JumpType tempType = new JumpType (myStringFull[1]);
 			string description  = getDescriptionLocalised(tempType, myStringFull[4]);
 
-
-			store.AppendValues (
-					//myStringFull[0], //don't display de uniqueID
-					myStringFull[1],	//name 
-					myStringFull[2], 	//startIn
-					myStringFull[3], 	//weight
-					description
-					);
+			//if we are going to execute: show all types
+			//if we are going to delete: show user defined types
+			if(testOrDelete || ! tempType.IsPredefined)
+				store.AppendValues (
+						//myStringFull[0], //don't display de uniqueID
+						myStringFull[1],	//name 
+						myStringFull[2], 	//startIn
+						myStringFull[3], 	//weight
+						description
+						);
 		}	
 	}
 
@@ -1072,15 +1091,21 @@ public class JumpsMoreWindow : EventMoreWindow
 			}
 			selectedDescription = (string) model.GetValue (iter, 3);
 
-			button_accept.Sensitive = true;
-			
-			//update graph image test on main window
-			button_selected.Click();
+			if(testOrDelete) {
+				button_accept.Sensitive = true;
+				//update graph image test on main window
+				button_selected.Click();
+			} else
+				button_delete_type.Sensitive = true;
 		}
 	}
 	
 	protected override void on_row_double_clicked (object o, Gtk.RowActivatedArgs args)
 	{
+		//return if we are to delete a test
+		if(!testOrDelete)
+			return;
+
 		TreeView tv = (TreeView) o;
 		TreeModel model;
 		TreeIter iter;
@@ -1101,6 +1126,10 @@ public class JumpsMoreWindow : EventMoreWindow
 		}
 	}
 	
+	protected override string [] findTestTypesInSessions() {
+		return SqliteJump.SelectJumps(-1, -1, "", selectedEventName); 
+	}
+	
 	void on_button_cancel_clicked (object o, EventArgs args)
 	{
 		JumpsMoreWindowBox.jumps_runs_more.Hide();
@@ -1155,12 +1184,16 @@ public class JumpsRjMoreWindow : EventMoreWindow
 	private double selectedLimitedValue;
 	private bool selectedUnlimited;
 	
-	public JumpsRjMoreWindow (Gtk.Window parent) {
+	public JumpsRjMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		//the glade window is the same as jumps_more
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
+		this.testOrDelete = testOrDelete;
+		
+		if(!testOrDelete)
+			jumps_runs_more.Title = Catalog.GetString("Delete test type defined by user");
 		
 		//put an icon to window
 		UtilGtk.IconWindow(jumps_runs_more);
@@ -1177,10 +1210,10 @@ public class JumpsRjMoreWindow : EventMoreWindow
 		initializeThings();
 	}
 	
-	static public JumpsRjMoreWindow Show (Gtk.Window parent)
+	static public JumpsRjMoreWindow Show (Gtk.Window parent, bool testOrDelete)
 	{
 		if (JumpsRjMoreWindowBox == null) {
-			JumpsRjMoreWindowBox = new JumpsRjMoreWindow (parent);
+			JumpsRjMoreWindowBox = new JumpsRjMoreWindow (parent, testOrDelete);
 		}
 		JumpsRjMoreWindowBox.jumps_runs_more.Show ();
 		
@@ -1237,15 +1270,18 @@ public class JumpsRjMoreWindow : EventMoreWindow
 			JumpType tempType = new JumpType (myStringFull[1]);
 			string description  = getDescriptionLocalised(tempType, myStringFull[6]);
 
-			store.AppendValues (
-					//myStringFull[0], //don't display de uniqueID
-					myStringFull[1],	//name 
-					myLimiter,		//jumps or seconds		
-					myLimiterValue,		//? or exact value
-					myStringFull[2], 	//startIn
-					myStringFull[3], 	//weight
-					description
-					);
+			//if we are going to execute: show all types
+			//if we are going to delete: show user defined types
+			if(testOrDelete || ! tempType.IsPredefined)
+				store.AppendValues (
+						//myStringFull[0], //don't display de uniqueID
+						myStringFull[1],	//name 
+						myLimiter,		//jumps or seconds		
+						myLimiterValue,		//? or exact value
+						myStringFull[2], 	//startIn
+						myStringFull[3], 	//weight
+						description
+						);
 		}	
 	}
 
@@ -1289,14 +1325,21 @@ public class JumpsRjMoreWindow : EventMoreWindow
 			}
 			selectedDescription = (string) model.GetValue (iter, 5);
 
-			button_accept.Sensitive = true;
-			//update graph image test on main window
-			button_selected.Click();
+			if(testOrDelete) {
+				button_accept.Sensitive = true;
+				//update graph image test on main window
+				button_selected.Click();
+			} else
+				button_delete_type.Sensitive = true;
 		}
 	}
 	
 	protected override void on_row_double_clicked (object o, Gtk.RowActivatedArgs args)
 	{
+		//return if we are to delete a test
+		if(!testOrDelete)
+			return;
+
 		TreeView tv = (TreeView) o;
 		TreeModel model;
 		TreeIter iter;
@@ -1334,6 +1377,9 @@ public class JumpsRjMoreWindow : EventMoreWindow
 		}
 	}
 	
+	protected override string [] findTestTypesInSessions() {
+		return SqliteJumpRj.SelectJumps(-1, -1, "", selectedEventName); 
+	}
 	
 	void on_button_cancel_clicked (object o, EventArgs args)
 	{
