@@ -32,9 +32,6 @@ public class PreferencesWindow {
 	
 	[Widget] Gtk.Window preferences;
 
-	[Widget] Gtk.ComboBox combo_port_linux;
-	[Widget] Gtk.ComboBox combo_port_windows;
-
 	[Widget] Gtk.Label label_database;
 	[Widget] Gtk.Label label_database_temp;
 	[Widget] Gtk.Label label_logs;
@@ -52,9 +49,16 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radiobutton_show_dj_index;
 	
 	[Widget] Gtk.CheckButton checkbutton_ask_deletion;
-	[Widget] Gtk.CheckButton checkbutton_height_preferred;
-	[Widget] Gtk.CheckButton checkbutton_meters_seconds_preferred;
-	[Widget] Gtk.CheckButton checkbutton_percent_kg_preferred;
+
+	[Widget] Gtk.RadioButton radio_elevation_height;
+	[Widget] Gtk.RadioButton radio_elevation_tf;
+	[Widget] Gtk.RadioButton radio_speed_ms;
+	[Widget] Gtk.RadioButton radio_speed_km;
+	[Widget] Gtk.RadioButton radio_weight_percent;
+	[Widget] Gtk.RadioButton radio_weight_kg;
+	[Widget] Gtk.TextView textview_power;
+
+
 //	[Widget] Gtk.Box hbox_language_row;
 //	[Widget] Gtk.Box hbox_combo_language;
 //	[Widget] Gtk.ComboBox combo_language;
@@ -67,10 +71,8 @@ public class PreferencesWindow {
 	//dialogMessage
 	private string languageIni;
 
-	string [] comboWindowsOptions;
-	
 
-	PreferencesWindow (string entryChronopic) {
+	PreferencesWindow () {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "preferences", null);
 		gladeXML.Autoconnect(this);
@@ -78,34 +80,6 @@ public class PreferencesWindow {
 		//put an icon to window
 		UtilGtk.IconWindow(preferences);
 
-		//combo port stuff
-		comboWindowsOptions = new string[257];
-		int count = 0;
-		for (int i=1; i <= 257; i ++)
-			comboWindowsOptions[i-1] = "COM" + i;
-
-		if(Util.IsWindows()) {
-			UtilGtk.ComboUpdate(combo_port_windows, comboWindowsOptions, comboWindowsOptions[0]);
-			
-			if(entryChronopic.Length > 0)
-				combo_port_windows.Active = UtilGtk.ComboMakeActive(comboWindowsOptions, entryChronopic);
-			else
-				combo_port_windows.Active = 0; //first option
-		} else {
-			string [] usbSerial = Directory.GetFiles("/dev/", "ttyUSB*");
-			string [] serial = Directory.GetFiles("/dev/", "ttyS*");
-			string [] all = Util.AddArrayString(usbSerial, serial);
-			string [] def = Util.StringToStringArray(Constants.ChronopicDefaultPortLinux);
-			string [] allWithDef = Util.AddArrayString(def, all);
-	
-			UtilGtk.ComboUpdate(combo_port_linux, allWithDef, Constants.ChronopicDefaultPortLinux);
-			
-			if(entryChronopic.Length > 0)
-				combo_port_linux.Active = UtilGtk.ComboMakeActive(allWithDef, entryChronopic);
-			else 
-				combo_port_linux.Active = 0; //first option
-		}
-
 		label_database.Visible = false;
 		label_database_temp.Visible = false;
 
@@ -115,21 +89,13 @@ public class PreferencesWindow {
 		//label_logs.Text = Log.GetDir();
 	}
 	
-	static public PreferencesWindow Show (string entryChronopic, int digitsNumber, bool showHeight, bool showPower,  
+	static public PreferencesWindow Show (int digitsNumber, bool showHeight, bool showPower,  
 			bool showInitialSpeed, bool showAngle, bool showQIndex, bool showDjIndex,
 			bool askDeletion, bool weightStatsPercent, bool heightPreferred, bool metersSecondsPreferred, 
 			string language, bool allowFinishRjAfterTime)
 	{
 		if (PreferencesWindowBox == null) {
-			PreferencesWindowBox = new PreferencesWindow (entryChronopic);
-		}
-
-		if(Util.IsWindows()) {
-			PreferencesWindowBox.combo_port_linux.Hide();
-			PreferencesWindowBox.combo_port_windows.Show();
-		} else {
-			PreferencesWindowBox.combo_port_windows.Hide();
-			PreferencesWindowBox.combo_port_linux.Show();
+			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
 		PreferencesWindowBox.languageIni = language;
@@ -152,10 +118,13 @@ public class PreferencesWindow {
 		else 
 			PreferencesWindowBox.checkbutton_height.Active = false; 
 		
-		if(showPower) 
+		if(showPower) {
 			PreferencesWindowBox.checkbutton_power.Active = true; 
-		else 
+			PreferencesWindowBox.textview_power.Show();
+		} else {
 			PreferencesWindowBox.checkbutton_power.Active = false; 
+			PreferencesWindowBox.textview_power.Hide();
+		}
 		
 
 		if(showInitialSpeed)  
@@ -191,21 +160,21 @@ public class PreferencesWindow {
 		
 
 		if(weightStatsPercent)  
-			PreferencesWindowBox.checkbutton_percent_kg_preferred.Active = true; 
+			PreferencesWindowBox.radio_weight_percent.Active = true; 
 		else 
-			PreferencesWindowBox.checkbutton_percent_kg_preferred.Active = false; 
+			PreferencesWindowBox.radio_weight_kg.Active = true; 
 		
 
 		if(heightPreferred)  
-			PreferencesWindowBox.checkbutton_height_preferred.Active = true; 
+			PreferencesWindowBox.radio_elevation_height.Active = true; 
 		else 
-			PreferencesWindowBox.checkbutton_height_preferred.Active = false; 
+			PreferencesWindowBox.radio_elevation_tf.Active = true; 
 		
 
 		if(metersSecondsPreferred)  
-			PreferencesWindowBox.checkbutton_meters_seconds_preferred.Active = true; 
+			PreferencesWindowBox.radio_speed_ms.Active = true; 
 		else 
-			PreferencesWindowBox.checkbutton_meters_seconds_preferred.Active = false; 
+			PreferencesWindowBox.radio_speed_km.Active = true; 
 		
 
 		PreferencesWindowBox.preferences.Show ();
@@ -252,6 +221,12 @@ public class PreferencesWindow {
 			hbox_indexes.Hide();
 	}
 		
+	private void on_checkbutton_power_clicked (object o, EventArgs args) {
+		if(checkbutton_power.Active)
+			textview_power.Show();
+		else
+			textview_power.Hide();
+	}
 	
 	void on_button_cancel_clicked (object o, EventArgs args)
 	{
@@ -358,14 +333,6 @@ public class PreferencesWindow {
 	void on_button_accept_clicked (object o, EventArgs args)
 	{
 		/* the falses are for the dbcon that is not opened */
-
-		
-		if(Util.IsWindows()) 
-			SqlitePreferences.Update("chronopicPort", UtilGtk.ComboGetActive(combo_port_windows), false);
-		else
-			SqlitePreferences.Update("chronopicPort", UtilGtk.ComboGetActive(combo_port_linux), false);
-		//SqlitePreferences.Update("chronopicPort", label_port.Text.ToString(), false);
-		
 		SqlitePreferences.Update("digitsNumber", UtilGtk.ComboGetActive(combo_decimals), false);
 		SqlitePreferences.Update("showHeight", PreferencesWindowBox.checkbutton_height.Active.ToString(), false);
 		SqlitePreferences.Update("showPower", PreferencesWindowBox.checkbutton_power.Active.ToString(), false);
@@ -383,9 +350,9 @@ public class PreferencesWindow {
 		
 		
 		SqlitePreferences.Update("askDeletion", PreferencesWindowBox.checkbutton_ask_deletion.Active.ToString(), false);
-		SqlitePreferences.Update("weightStatsPercent", PreferencesWindowBox.checkbutton_percent_kg_preferred.Active.ToString(), false);
-		SqlitePreferences.Update("heightPreferred", PreferencesWindowBox.checkbutton_height_preferred.Active.ToString(), false);
-		SqlitePreferences.Update("metersSecondsPreferred", PreferencesWindowBox.checkbutton_meters_seconds_preferred.Active.ToString(), false);
+		SqlitePreferences.Update("weightStatsPercent", PreferencesWindowBox.radio_weight_percent.Active.ToString(), false);
+		SqlitePreferences.Update("heightPreferred", PreferencesWindowBox.radio_elevation_height.Active.ToString(), false);
+		SqlitePreferences.Update("metersSecondsPreferred", PreferencesWindowBox.radio_speed_ms.Active.ToString(), false);
 		
 		/*
 		if(Util.IsWindows()) {
@@ -409,19 +376,10 @@ public class PreferencesWindow {
 		PreferencesWindowBox = null;
 	}
 
-
-	private void on_button_help_clicked (object o, EventArgs args) {
-		new HelpPorts();
-	}
-
 	public Button Button_accept 
 	{
-		set {
-			button_accept = value;	
-		}
-		get {
-			return button_accept;
-		}
+		set { button_accept = value; }
+		get { return button_accept;  }
 	}
 
 }
